@@ -25,17 +25,14 @@ class Network3Medusa():
             for interface in json_dict['TABLE_interface']['ROW_interface']:
                 if first:
                     first = False
-                    raw_json=interface
-                    print("first")
-                    self.add_file_to_hedera(f"{ str(raw_json) },")
+                    raw_json=str(interface).replace("\'", "\"")
+                    self.add_file_to_hedera(f"{ raw_json },")
                 elif interface == json_dict['TABLE_interface']['ROW_interface'][-1]:
-                    raw_json=interface
-                    print("last")
-                    self.append_file_to_hedera(str(raw_json))
+                    raw_json=str(interface).replace("\'", "\"")
+                    self.append_file_to_hedera(raw_json)
                 else:
-                    raw_json=interface
-                    print("middle")
-                    self.append_file_to_hedera(f"{ str(raw_json) },")
+                    raw_json=str(interface).replace("\'", "\"")
+                    self.append_file_to_hedera(f"{ raw_json },")
 
             query = FileInfoQuery().setFileId(self.fileId)
             info = query.execute(self.client)
@@ -60,8 +57,11 @@ class Network3Medusa():
         self.nodeId = resp.nodeId.toString()
         receipt = resp.getReceipt(self.client)
         self.fileId = receipt.fileId
+        query = FileInfoQuery().setFileId(self.fileId)
+        info = query.execute(self.client)
         print("file: ",  self.fileId.toString())
-
+        print("File size according to `FileInfoQuery`: ", info.size)
+        
     def append_file_to_hedera(self, interface):
         tran = (FileAppendTransaction()
                 .setFileId(self.fileId)
